@@ -152,7 +152,7 @@ def update_config(http_host:str, run_id: int , exp_name: str, team_name: str , i
 def send_alert(http_host:str, data: Dict ) -> Dict:
     url = parse_result_wraaper(http_host,URL_SEND_ALERT)
     rsp = post(url, data)
-    logger.debug("send_alert() response : " + rsp["message"])
+    logger.debug("send_alert() response : " + rsp["result"])
     return rsp
 
 def finish(http_host: str ,data: Dict) -> Dict:
